@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 # @XZGUtil    : 2021-01-09 19:36
-# @Site    : 
+# @Site    :
 # @File    : logger.py
 # @Software: PyCharm
 """
@@ -60,10 +60,4 @@ def async_logit(func):
         return result
     return with_logging
 
-# demo:
-@async_logit
-async def test():
-    return 6666
 
-loop = asyncio.get_event_loop()
-loop.run_until_complete(test())
